@@ -15,26 +15,26 @@ $good = [
                              'name' => 'more.stuff.example.com.',
                              'action' => 'create',
                              'type' => 'A',
-                             'value' => '127.0.0.1',
+                             'records' => [ '127.0.0.1' ],
                              'ttl' => 3600
                            },
                            {
                              'name' => 'smtp.example.com.',
                              'action' => 'create',
-                             'value' => '127.0.0.1',
+                             'records' => [ '127.0.0.1' ],
                              'ttl' => 3600,
                              'type' => 'A'
                            },
                            {
                              'name' => 'mail.example.com.',
                              'ttl' => 3600,
-                             'value' => '127.0.0.2',
+                             'records' => [ '127.0.0.2' ],
                              'type' => 'A',
                              'action' => 'create'
                            },
                            {
                              'name' => 'www.example.com.',
-                             'value' => '127.0.0.1',
+                             'records' => [ '127.0.0.1' ],
                              'ttl' => 3600,
                              'type' => 'A',
                              'action' => 'create'
@@ -48,6 +48,15 @@ $good = [
                                           ],
                              'name' => 'example._domainkey.example.com.'
                            },
+                           {
+                             'type' => 'TXT',
+                             'records' => [
+                                            '"For a *great* time call: 555-1213"'
+                                          ],
+                             'action' => 'create',
+                             'ttl' => 3600,
+                             'name' => 'bob.people.example.com.'
+                           },
                            {
                              'name' => 'david.people.example.com.',
                              'records' => [
@@ -59,7 +68,7 @@ $good = [
                            },
                            {
                              'name' => 'even.more.stuff.example.com.',
-                             'value' => '127.0.0.1',
+                             'records' => [ '127.0.0.1' ],
                              'type' => 'A',
                              'ttl' => 3600,
                              'action' => 'create'
@@ -67,12 +76,21 @@ $good = [
                            {
                              'action' => 'create',
                              'type' => 'A',
-                             'value' => '127.0.0.1',
+                             'records' => [ '127.0.0.1' ],
                              'ttl' => 3600,
                              'name' => 'ns2.example.com.'
                            },
                            {
-                             'value' => '127.0.0.1',
+                             'type' => 'NS',
+                             'name' => 'subdomain.example.com.',
+                             'action' => 'create',
+                             'ttl' => 3600,
+                             'records' => [
+                                            'subdomain-ns.example.com.'
+                                          ]
+                           },
+                           {
+                             'records' => [ '127.0.0.1' ],
                              'ttl' => 3600,
                              'type' => 'A',
                              'action' => 'create',
@@ -96,7 +114,7 @@ $good = [
                            },
                            {
                              'type' => 'A',
-                             'value' => '127.0.0.1',
+                             'records' => [ '127.0.0.1' ],
                              'ttl' => 3600,
                              'action' => 'create',
                              'name' => 'ns1.example.com.'
@@ -109,7 +127,7 @@ $good = [
                              'name' => 'www2.example.com.'
                            },
                            {
-                             'value' => '127.0.0.1',
+                             'records' => [ '127.0.0.1' ],
                              'ttl' => 3600,
                              'type' => 'A',
                              'action' => 'create',
@@ -128,7 +146,7 @@ $good = [
                              'type' => 'TXT',
                              'name' => 'example.com.',
                              'records' => [
-                                            '"Weird characters: \"hello\"\074script\076\044\044)(*\046\136\045\044\043\100\041\176\140\133\135\173\175\174:;\"\'\054.\057\074\076\077\000\011\012"',
+                                            '"Weird characters: \"hello\"\074script\076\044\044)(*\046\136\045\044\043\100\041\176\140\133\135\173\175\134\174:;\"\'\054.\057\074\076\077\000\011\012"',
                                             '"another different text record"',
                                             '"v=spf1 mx -all"',
                                           ]
@@ -147,16 +165,26 @@ $good = [
                              'name' => 'example.com.',
                              'action' => 'create',
                              'ttl' => 3600,
-                             'value' => '127.0.0.3',
+                             'records' => [ '127.0.0.3' ],
                              'type' => 'A'
                            },
                            {
                              'name' => 'tons.of.stuff.example.com.',
                              'action' => 'create',
                              'ttl' => 3600,
-                             'value' => '127.0.0.1',
+                             'records' => [ '127.0.0.1' ],
                              'type' => 'A'
-                           }
+                           },
+                           {
+                             'records' => [
+                                            '127.0.0.4',
+                                            '127.0.0.5'
+                                          ],
+                             'action' => 'create',
+                             'type' => 'A',
+                             'ttl' => 3600,
+                             'name' => 'round-robin.example.com.'
+                           },
                          ]
           }
         ];
